gvproxy_set_log_callback

Function gvproxy_set_log_callback 

pub unsafe extern "C" fn gvproxy_set_log_callback(
    callback: *const c_void,
)
Set the log callback function for routing gvproxy logs to Rust

When set, Go’s slog handler will call this callback for all log messages, allowing integration with Rust’s tracing system.

Arguments

  • callback - Function pointer to Rust logging callback, or NULL to disable

Safety

The callback must be thread-safe and must not panic. Pass NULL to restore default stderr logging.